@@ -54,6 +54,8 @@ struct _ImageLoaderPrivateData {
 	gboolean              done;
 	gboolean              error;
 	gboolean              loader_done;
+	gboolean              interrupted;
+	gboolean              loading;
 
 	GTimer               *timer;
 	int                   priority;
@@ -79,9 +81,9 @@ struct _ImageLoaderPrivateData {
 
 
 enum {
-	ERROR,
-	DONE,
-	PROGRESS,
+	IMAGE_ERROR,
+	IMAGE_DONE,
+	IMAGE_PROGRESS,
 	LAST_SIGNAL
 };
 
@@ -105,8 +107,10 @@ image_loader_finalize__step2 (GObject *object)
 	if (priv->animation)
 		g_object_unref (G_OBJECT (priv->animation));
 
-	if (priv->uri)
+	if (priv->uri) {
 		gnome_vfs_uri_unref (priv->uri);
+		priv->uri = NULL;
+	}
 	
 	g_timer_destroy (priv->timer);
 
@@ -166,29 +170,29 @@ image_loader_class_init (ImageLoaderClass *class)
 
 	parent_class = g_type_class_peek_parent (class);
 
-	image_loader_signals[ERROR] =
-		g_signal_new ("error",
+	image_loader_signals[IMAGE_ERROR] =
+		g_signal_new ("image_error",
 			      G_TYPE_FROM_CLASS (class),
 			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (ImageLoaderClass, error),
+			      G_STRUCT_OFFSET (ImageLoaderClass, image_error),
 			      NULL, NULL,
 			      gthumb_marshal_VOID__VOID,
 			      G_TYPE_NONE, 
 			      0);
-	image_loader_signals[DONE] =
-		g_signal_new ("done",
+	image_loader_signals[IMAGE_DONE] =
+		g_signal_new ("image_done",
 			      G_TYPE_FROM_CLASS (class),
 			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (ImageLoaderClass, done),
+			      G_STRUCT_OFFSET (ImageLoaderClass, image_done),
 			      NULL, NULL,
 			      gthumb_marshal_VOID__VOID,
 			      G_TYPE_NONE, 
 			      0);
-	image_loader_signals[PROGRESS] =
-		g_signal_new ("progress",
+	image_loader_signals[IMAGE_PROGRESS] =
+		g_signal_new ("image_progress",
 			      G_TYPE_FROM_CLASS (class),
 			      G_SIGNAL_RUN_FIRST,
-			      G_STRUCT_OFFSET (ImageLoaderClass, progress),
+			      G_STRUCT_OFFSET (ImageLoaderClass, image_progress),
 			      NULL, NULL,
 			      gthumb_marshal_VOID__FLOAT,
 			      G_TYPE_NONE, 
@@ -196,9 +200,9 @@ image_loader_class_init (ImageLoaderClass *class)
 
 	object_class->finalize = image_loader_finalize;
 
-	class->error = NULL;
-	class->done = NULL;
-	class->progress = NULL;
+	class->image_error = NULL;
+	class->image_done = NULL;
+	class->image_progress = NULL;
 }
 
 static void * load_image_thread (void *thread_data);
@@ -208,7 +212,7 @@ image_loader_init (ImageLoader *il)
 {
 	ImageLoaderPrivateData *priv;
 
-	il->priv = g_new (ImageLoaderPrivateData, 1);
+	il->priv = g_new0 (ImageLoaderPrivateData, 1);
 	priv = il->priv;
 
 	priv->pixbuf = NULL;
@@ -223,6 +227,7 @@ image_loader_init (ImageLoader *il)
 	priv->done = FALSE;
 	priv->error = FALSE;
 	priv->loader_done = FALSE;
+	priv->interrupted = FALSE;
 
 	priv->timer = g_timer_new ();
 	priv->priority = GNOME_VFS_PRIORITY_DEFAULT;
@@ -308,8 +313,10 @@ image_loader_set_path (ImageLoader *il,
 
 	g_mutex_lock (priv->yes_or_no);
 
-	if (priv->uri != NULL)
+	if (priv->uri != NULL) {
 		gnome_vfs_uri_unref (priv->uri);
+		priv->uri = NULL;
+	}
 	escaped_path = gnome_vfs_escape_path_string (path);
 	priv->uri = gnome_vfs_uri_new (escaped_path);
 	g_free (escaped_path);
@@ -331,9 +338,12 @@ image_loader_set_uri (ImageLoader       *il,
 
 	g_mutex_lock (priv->yes_or_no);
 
-	if (priv->uri != NULL)
+	if (priv->uri != NULL) {
 		gnome_vfs_uri_unref (priv->uri);
-	priv->uri = gnome_vfs_uri_dup (uri);
+		priv->uri = NULL;
+	}
+	if (uri != NULL)
+		priv->uri = gnome_vfs_uri_dup (uri);
 
 	g_mutex_unlock (priv->yes_or_no);
 }
@@ -435,6 +445,22 @@ image_loader_sync_pixbuf_from_loader (ImageLoader     *il,
 }
 
 
+static void 
+image_loader_interrupted (ImageLoader *il)
+{
+	ImageLoaderPrivateData *priv = il->priv;
+
+	g_mutex_lock (priv->yes_or_no);
+	priv->error = TRUE;
+	g_mutex_unlock (priv->yes_or_no);
+
+	image_loader_stop_common (il, 
+				  priv->done_func, 
+				  priv->done_func_data, 
+				  TRUE);
+}
+
+
 static void 
 image_loader_done (ImageLoader *il)
 {
@@ -529,27 +555,33 @@ image_loader_stop__final_step (ImageLoader *il)
 	error = priv->error;
 	priv->done = TRUE;
 	g_mutex_unlock (priv->yes_or_no);
-	
-	if (! error) 
+
+	if (! error && ! priv->interrupted && priv->loading) 
 		image_loader_sync_pixbuf (il);
+	priv->loading = FALSE;
 	
 	priv->done_func = NULL;
 	if (done_func != NULL)
 		(*done_func) (priv->done_func_data);
 	
-	if (! priv->emit_signal)
-		return;
+	if (! priv->emit_signal || priv->interrupted) {
+		priv->interrupted = FALSE;
 		
+		return;
+	}
+		
+	priv->interrupted = FALSE;
+
 	if (error)
 		g_signal_emit (G_OBJECT (il), 
-			       image_loader_signals[ERROR], 0);
+			       image_loader_signals[IMAGE_ERROR], 0);
 	else
 		g_signal_emit (G_OBJECT (il), 
-			       image_loader_signals[DONE], 0);
+			       image_loader_signals[IMAGE_DONE], 0);
 }
 
 
-static gint
+static int
 check_thread (gpointer data)
 {
 	ImageLoader            *il = data;
@@ -571,7 +603,10 @@ check_thread (gpointer data)
 
 	/**/
 
-	if (loader_done && done) 
+	if (loader_done && priv->interrupted)
+		image_loader_interrupted (il);
+
+	else if (loader_done && done) 
 		image_loader_done (il);
 	
 	else if (loader_done && error) 
@@ -643,6 +678,7 @@ image_loader_start__step2 (ImageLoader *il)
 	priv->done = FALSE;
 	priv->error = FALSE;
 	priv->loader_done = FALSE;
+	priv->loading = TRUE;
 	g_mutex_unlock (priv->yes_or_no);
 
 	uri_list = g_list_prepend (NULL, priv->uri);
@@ -665,7 +701,6 @@ image_loader_start (ImageLoader *il)
 	g_return_if_fail (il != NULL);
 	priv = il->priv;
 	g_return_if_fail (priv->uri != NULL);
-
 	image_loader_stop_common (il, (DoneFunc) image_loader_start__step2, il, FALSE);
 }
 
@@ -721,7 +756,7 @@ image_loader_stop (ImageLoader *il,
 		   gpointer     done_func_data)
 {
 	ImageLoaderPrivateData *priv;
-	gboolean                emit_sig;
+	/*gboolean                emit_sig;*/
 
 	g_return_if_fail (il != NULL);
 
@@ -731,10 +766,19 @@ image_loader_stop (ImageLoader *il,
 	priv->error = FALSE;
 	g_mutex_unlock (priv->yes_or_no);
 
-	/* emit a signal only if there is an operation to stop */
-	emit_sig = (priv->info_handle != NULL);
+	if (priv->loading) {
+		priv->emit_signal = TRUE;
+		priv->interrupted = TRUE;
+		priv->done_func = done_func;
+		priv->done_func_data = done_func_data;
+	} else
+		image_loader_stop_common (il, done_func, done_func_data, FALSE);
 
-	image_loader_stop_common (il, done_func, done_func_data, emit_sig);
+	/* FIXME: emit a signal only if there is an operation to stop */
+	/*
+	  emit_sig = (priv->info_handle != NULL);
+	  image_loader_stop_common (il, done_func, done_func_data, emit_sig);
+	*/
 }
 
 
@@ -908,9 +952,9 @@ image_loader_load_from_pixbuf_loader (ImageLoader *il,
 	g_mutex_unlock (il->priv->yes_or_no);
 
 	if (error)
-		g_signal_emit (G_OBJECT (il), image_loader_signals[ERROR], 0);
+		g_signal_emit (G_OBJECT (il), image_loader_signals[IMAGE_ERROR], 0);
 	else
-		g_signal_emit (G_OBJECT (il), image_loader_signals[DONE], 0);
+		g_signal_emit (G_OBJECT (il), image_loader_signals[IMAGE_DONE], 0);
 }
 
 
@@ -970,8 +1014,8 @@ image_loader_load_from_image_loader (ImageLoader *to,
 	g_mutex_unlock (from->priv->yes_or_no);
 
 	if (error)
-		g_signal_emit (G_OBJECT (to), image_loader_signals[ERROR], 0);
+		g_signal_emit (G_OBJECT (to), image_loader_signals[IMAGE_ERROR], 0);
 	else
-		g_signal_emit (G_OBJECT (to), image_loader_signals[DONE], 0);
+		g_signal_emit (G_OBJECT (to), image_loader_signals[IMAGE_DONE], 0);
 }
 
