@@ -204,7 +204,7 @@ catalog_list_get_path_from_row (CatalogList *cat_list,
 				gint row)
 {
 	GtkTreePath *path;
-	gchar *result;
+	char        *result;
 
 	g_return_val_if_fail (cat_list != NULL, NULL);
 
@@ -244,7 +244,7 @@ gboolean
 catalog_list_is_catalog (CatalogList *cat_list,
 			 GtkTreeIter *iter)
 {
-	gint type;
+	int type;
 
 	g_return_val_if_fail (cat_list != NULL, FALSE);
 
@@ -260,7 +260,7 @@ gboolean
 catalog_list_is_dir (CatalogList *cat_list,
 		     GtkTreeIter *iter)
 {
-	gint type;
+	int type;
 
 	g_return_val_if_fail (cat_list != NULL, FALSE);
 
@@ -276,7 +276,7 @@ gboolean
 catalog_list_is_search (CatalogList *cat_list,
 			GtkTreeIter *iter)
 {
-	gint type;
+	int type;
 
 	g_return_val_if_fail (cat_list != NULL, FALSE);
 
@@ -430,7 +430,10 @@ catalog_list_refresh (CatalogList *cat_list)
 		else 
 			pixbuf = dir_pixbuf;
 
-		utf8_name = g_locale_to_utf8 (name, -1, NULL, NULL, NULL);
+		utf8_name = g_filename_to_utf8 (name, -1, NULL, NULL, NULL);
+
+		if (utf8_name == NULL)
+			utf8_name = g_strdup (_("(Invalid Name)"));
 
 		gtk_list_store_append (cat_list->list_store, &iter);
 		gtk_list_store_set (cat_list->list_store, &iter,
@@ -459,7 +462,10 @@ catalog_list_refresh (CatalogList *cat_list)
 			pixbuf = catalog_pixbuf;
 		}
 
-		utf8_name = g_locale_to_utf8 (name, -1, NULL, NULL, NULL);
+		utf8_name = g_filename_to_utf8 (name, -1, NULL, NULL, NULL);
+
+		if (utf8_name == NULL)
+			utf8_name = g_strdup (_("(Invalid Name)"));
 
 		gtk_list_store_append (cat_list->list_store, &iter);
 		gtk_list_store_set (cat_list->list_store, &iter,
