@@ -33,6 +33,7 @@
 #include "catalog-web-exporter.h"
 #include "comments.h"
 #include "file-utils.h"
+#include "exif-utils.h"
 #include "dlg-file-utils.h"
 #include "gthumb-init.h"
 #include "gthumb-marshal.h"
@@ -43,13 +44,6 @@
 #include "glib-utils.h"
 #include "albumtheme-private.h"
 
-#ifdef HAVE_LIBEXIF
-#include <exif-data.h>
-#include <exif-content.h>
-#include <exif-entry.h>
-#endif /* HAVE_LIBEXIF */
-
-
 #define DATE_FORMAT _("%d %B %Y, %H:%M")
 
 
@@ -60,10 +54,10 @@ typedef enum {
 } GthTagVisibility;
 
 enum {
-	DONE,
-	PROGRESS,
-	INFO,
-	START_COPYING,
+	WEB_EXPORTER_DONE,
+	WEB_EXPORTER_PROGRESS,
+	WEB_EXPORTER_INFO,
+	WEB_EXPORTER_START_COPYING,
 	LAST_SIGNAL
 };
 
@@ -76,8 +70,6 @@ extern FILE         *yyin;
 #define DEFAULT_THUMB_SIZE 100
 #define DEFAULT_INDEX_FILE "index.html"
 #define SAVING_TIMEOUT 5
-#define DEFAULT_MAX_WIDTH 640
-#define DEFAULT_MAX_HEIGHT 480
 
 
 typedef struct {
@@ -255,41 +247,41 @@ catalog_web_exporter_class_init (CatalogWebExporterClass *class)
 
 	parent_class = g_type_class_peek_parent (class);
 
-	catalog_web_exporter_signals[DONE] =
-		g_signal_new ("done",
+	catalog_web_exporter_signals[WEB_EXPORTER_DONE] =
+		g_signal_new ("web_exporter_done",
 			      G_TYPE_FROM_CLASS (class),
 			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (CatalogWebExporterClass, done),
+			      G_STRUCT_OFFSET (CatalogWebExporterClass, web_exporter_done),
 			      NULL, NULL,
 			      gthumb_marshal_VOID__VOID,
 			      G_TYPE_NONE, 
 			      0);
 
-	catalog_web_exporter_signals[PROGRESS] =
-		g_signal_new ("progress",
+	catalog_web_exporter_signals[WEB_EXPORTER_PROGRESS] =
+		g_signal_new ("web_exporter_progress",
 			      G_TYPE_FROM_CLASS (class),
 			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (CatalogWebExporterClass, progress),
+			      G_STRUCT_OFFSET (CatalogWebExporterClass, web_exporter_progress),
 			      NULL, NULL,
 			      gthumb_marshal_VOID__FLOAT,
 			      G_TYPE_NONE, 
 			      1, G_TYPE_FLOAT);
 
-	catalog_web_exporter_signals[INFO] =
-		g_signal_new ("info",
+	catalog_web_exporter_signals[WEB_EXPORTER_INFO] =
+		g_signal_new ("web_exporter_info",
 			      G_TYPE_FROM_CLASS (class),
 			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (CatalogWebExporterClass, info),
+			      G_STRUCT_OFFSET (CatalogWebExporterClass, web_exporter_info),
 			      NULL, NULL,
 			      gthumb_marshal_VOID__STRING,
 			      G_TYPE_NONE, 
 			      1, G_TYPE_STRING);
 
-	catalog_web_exporter_signals[START_COPYING] =
-		g_signal_new ("start_copying",
+	catalog_web_exporter_signals[WEB_EXPORTER_START_COPYING] =
+		g_signal_new ("web_exporter_start_copying",
 			      G_TYPE_FROM_CLASS (class),
 			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (CatalogWebExporterClass, start_copying),
+			      G_STRUCT_OFFSET (CatalogWebExporterClass, web_exporter_start_copying),
 			      NULL, NULL,
 			      gthumb_marshal_VOID__VOID,
 			      G_TYPE_NONE, 
@@ -315,9 +307,10 @@ catalog_web_exporter_init (CatalogWebExporter *ce)
 	ce->thumb_width = DEFAULT_THUMB_SIZE;
 	ce->thumb_height = DEFAULT_THUMB_SIZE;
 
+	ce->copy_images = FALSE;
 	ce->resize_images = FALSE;
-	ce->resize_max_width = DEFAULT_MAX_WIDTH;
-	ce->resize_max_height = DEFAULT_MAX_HEIGHT;
+	ce->resize_max_width = 0;
+	ce->resize_max_height = 0;
 
 	ce->preview_max_width = 0;
 	ce->preview_max_height = 0;
@@ -450,6 +443,9 @@ catalog_web_exporter_set_resize_images (CatalogWebExporter *ce,
 	if (resize) {
 		ce->resize_max_width = max_width;
 		ce->resize_max_height = max_height;
+	} else {
+		ce->resize_max_width = 0;
+		ce->resize_max_height = 0;
 	}
 }
 
@@ -494,7 +490,10 @@ catalog_web_exporter_set_preview_size (CatalogWebExporter *ce,
 {
 	g_return_if_fail (IS_CATALOG_WEB_EXPORTER (ce));
 
-	if ((ce->resize_max_width > 0) && (ce->resize_max_height > 0)) {
+	if (ce->copy_images 
+	    && ce->resize_images 
+	    && (ce->resize_max_width > 0) 
+	    && (ce->resize_max_height > 0)) {
 		if (width > ce->resize_max_width) 
 			width = ce->resize_max_width;
 		if (height > ce->resize_max_height) 
@@ -871,101 +870,6 @@ get_preview_filename (CatalogWebExporter *ce,
 }
 
 
-#ifdef HAVE_LIBEXIF
-
-static time_t
-get_exif_time (const char *filename)
-{
-	ExifData     *edata;
-	unsigned int  i, j;
-	time_t        time = 0;
-	struct tm     tm = { 0, };
-
-	edata = exif_data_new_from_file (filename);
-
-	if (edata == NULL) 
-                return (time_t)0;
-
-	for (i = 0; i < EXIF_IFD_COUNT; i++) {
-		ExifContent *content = edata->ifd[i];
-
-		if (! edata->ifd[i] || ! edata->ifd[i]->count) 
-			continue;
-
-		for (j = 0; j < content->count; j++) {
-			ExifEntry   *e = content->entries[j];
-			char        *data;
-
-			if (! content->entries[j]) 
-				continue;
-
-			if ((e->tag != EXIF_TAG_DATE_TIME) &&
-			    (e->tag != EXIF_TAG_DATE_TIME_ORIGINAL) &&
-			    (e->tag != EXIF_TAG_DATE_TIME_DIGITIZED))
-				continue;
-
-			data = g_strdup (e->data);
-			data[4] = data[7] = data[10] = data[13] = data[16] = '\0';
-
-			tm.tm_year = atoi (data) - 1900;
-			tm.tm_mon  = atoi (data + 5) - 1;
-			tm.tm_mday = atoi (data + 8);
-			tm.tm_hour = atoi (data + 11);
-			tm.tm_min  = atoi (data + 14);
-			tm.tm_sec  = atoi (data + 17);
-			time = mktime (&tm);
-
-			g_free (data);
-
-			break;
-		}
-	}
-
-	exif_data_unref (edata);
-
-	return time;
-}
-
-
-static char *
-get_exif_tag (const char *filename, ExifTag etag)
-{
-	ExifData     *edata;
-	unsigned int  i, j;
-
-	edata = exif_data_new_from_file (filename);
-
-	if (edata == NULL) 
-		return g_strdup ("-");
-
-	for (i = 0; i < EXIF_IFD_COUNT; i++) {
-		ExifContent *content = edata->ifd[i];
-
-		if (! edata->ifd[i] || ! edata->ifd[i]->count) 
-			continue;
-
-		for (j = 0; j < content->count; j++) {
-			ExifEntry *e = content->entries[j];
-
-			if (! content->entries[j]) 
-				continue;
-
-			if (e->tag == etag) {
-				char *retval = g_locale_to_utf8 (exif_entry_get_value (e), -1, 0, 0, 0);
-				exif_data_unref (edata);
-				return retval;
-			}
-		}
-	}
-
-	exif_data_unref (edata);
-
-	return g_strdup ("-");
-}
-
-#endif /* HAVE_LIBEXIF */
-
-
 static char*
 get_current_date (void)
 {
@@ -1335,8 +1239,7 @@ gth_parsed_doc_print (GList              *document,
 			idx = get_image_idx (tag, ce);
 			idata = g_list_nth (ce->file_list, idx)->data;
 #ifdef HAVE_LIBEXIF
-			line = get_exif_tag (idata->src_filename, 
-					     EXIF_TAG_APERTURE_VALUE);
+			line = get_exif_aperture_value (idata->src_filename);
 			write_line (line, fout);
 #endif /* HAVE_LIBEXIF */
 			break;
@@ -1431,7 +1334,7 @@ exporter_set_info (CatalogWebExporter *ce,
 {
 	g_free (ce->info);
 	ce->info = g_strdup (info);
-	g_signal_emit (G_OBJECT (ce), catalog_web_exporter_signals[INFO], 
+	g_signal_emit (G_OBJECT (ce), catalog_web_exporter_signals[WEB_EXPORTER_INFO], 
 		       0,
 		       ce->info);
 }
@@ -1443,7 +1346,7 @@ export__final_step (GnomeVFSResult  result,
 {
 	CatalogWebExporter *ce = data;
 	free_parsed_docs (ce);
-	g_signal_emit (G_OBJECT (ce), catalog_web_exporter_signals[DONE], 0);
+	g_signal_emit (G_OBJECT (ce), catalog_web_exporter_signals[WEB_EXPORTER_DONE], 0);
 }
 
 
@@ -1465,7 +1368,7 @@ export__copy_to_destination__step2 (GnomeVFSResult  result,
 static void
 export__copy_to_destination (CatalogWebExporter *ce)
 {
-	g_signal_emit (G_OBJECT (ce), catalog_web_exporter_signals[START_COPYING], 0);
+	g_signal_emit (G_OBJECT (ce), catalog_web_exporter_signals[WEB_EXPORTER_START_COPYING], 0);
 
 	dlg_files_copy (ce->window,
 			ce->album_files,
@@ -1575,7 +1478,7 @@ save_thumbnail_cb (gpointer data)
 			char *filename;
 			
 			g_signal_emit (G_OBJECT (ce), 
-				       catalog_web_exporter_signals[PROGRESS],
+				       catalog_web_exporter_signals[WEB_EXPORTER_PROGRESS],
 				       0,
 				       (float) ce->image / ce->n_images);
 			
@@ -1641,7 +1544,7 @@ save_html_image_cb (gpointer data)
 		FILE      *fout;
 
 		g_signal_emit (G_OBJECT (ce), 
-			       catalog_web_exporter_signals[PROGRESS],
+			       catalog_web_exporter_signals[WEB_EXPORTER_PROGRESS],
 			       0,
 			       (float) ce->image / ce->n_images);
 
@@ -1706,7 +1609,7 @@ save_html_index_cb (gpointer data)
 		FILE *fout;
 
 		g_signal_emit (G_OBJECT (ce), 
-			       catalog_web_exporter_signals[PROGRESS],
+			       catalog_web_exporter_signals[WEB_EXPORTER_PROGRESS],
 			       0,
 			       (float) ce->page / ce->n_pages);
 
@@ -1770,8 +1673,6 @@ export__save_html_files (CatalogWebExporter *ce)
 static void
 load_next_file (CatalogWebExporter *ce)
 {
-	char *filename;
-
 	if (ce->interrupted) { 
 		if (ce->file_list != NULL) {
 			g_list_foreach (ce->file_list, 
@@ -1787,8 +1688,27 @@ load_next_file (CatalogWebExporter *ce)
 		return;
 	}
 
+	/**/
+
+	if (ce->file_to_load != NULL) {
+		ImageData *idata = ce->file_to_load->data;
+		
+		if (idata->preview != NULL) {
+			g_object_unref (idata->preview);
+			idata->preview = NULL;
+		}
+
+		if (idata->image != NULL) {
+			g_object_unref (idata->image);
+			idata->image = NULL;
+		}
+	}
+
+
+	/**/
+
 	g_signal_emit (G_OBJECT (ce), 
-		       catalog_web_exporter_signals[PROGRESS],
+		       catalog_web_exporter_signals[WEB_EXPORTER_PROGRESS],
 		       0,
 		       (float) ++ce->n_images_done / ce->n_images);
 
@@ -1802,7 +1722,7 @@ load_next_file (CatalogWebExporter *ce)
 		export__save_html_files (ce);
 
 	} else {
-		filename = IMAGE_DATA (ce->file_to_load->data)->src_filename;
+		char *filename = IMAGE_DATA (ce->file_to_load->data)->src_filename;
 		thumb_loader_set_path (ce->tloader, filename);
 		thumb_loader_start (ce->tloader);
 	}
@@ -1834,9 +1754,6 @@ save_image_preview_cb (gpointer data)
 				ce->album_files = g_list_prepend (ce->album_files, filename);
 			else
 				g_free (filename);
-		
-			g_object_unref (idata->preview);
-			idata->preview = NULL;
 		}
 	}
 
@@ -1873,9 +1790,6 @@ save_resized_image_cb (gpointer data)
 				ce->album_files = g_list_prepend (ce->album_files, filename);
 			else
 				g_free (filename);
-		
-			g_object_unref (idata->image);
-			idata->image = NULL;
 		}
 	}
 
@@ -1926,6 +1840,7 @@ export__copy_image (CatalogWebExporter *ce)
 	exporter_set_info (ce, _("Saving images"));
 
 	idata = ce->file_to_load->data;
+
 	dest_filename = get_image_filename (ce, idata, ce->tmp_location);
 	src_list = g_list_append (src_list, new_uri_from_path (idata->src_filename));
 	dest_list = g_list_append (dest_list, new_uri_from_path (dest_filename));
@@ -1981,11 +1896,10 @@ thumb_loader_done (ThumbLoader *tloader,
 	/* image */
 
 	il = thumb_loader_get_image_loader (tloader);
-	pixbuf = image_loader_get_pixbuf (il);
-	idata->image_width = gdk_pixbuf_get_width (pixbuf);
-	idata->image_height = gdk_pixbuf_get_height (pixbuf);
+	idata->image = pixbuf = image_loader_get_pixbuf (il);
+	g_object_ref (idata->image);
 
-	if (ce->resize_images) {
+	if (ce->copy_images && ce->resize_images) {
 		int w = gdk_pixbuf_get_width (pixbuf);
 		int h = gdk_pixbuf_get_height (pixbuf);
 		if ((w > ce->resize_max_width) || (h > ce->resize_max_height)) {
@@ -1999,15 +1913,14 @@ thumb_loader_done (ThumbLoader *tloader,
 			new_w  = MAX ((int) (w * factor + 0.5), 1);
 			new_h  = MAX ((int) (h * factor + 0.5), 1);
 			scaled = gdk_pixbuf_scale_simple (pixbuf, new_w, new_h, GDK_INTERP_BILINEAR);
+			g_object_unref (idata->image);
 			idata->image = scaled;
-			idata->image_width = gdk_pixbuf_get_width (idata->image);
-			idata->image_height = gdk_pixbuf_get_height (idata->image);
-		} else {
-			idata->image = pixbuf;
-			g_object_ref (idata->image);
-		}
+		} 
 	}
 
+	idata->image_width = gdk_pixbuf_get_width (idata->image);
+	idata->image_height = gdk_pixbuf_get_height (idata->image);
+
 	/* preview */
 
 	il = thumb_loader_get_image_loader (tloader);
@@ -2017,6 +1930,7 @@ thumb_loader_done (ThumbLoader *tloader,
 	if ((ce->preview_max_width > 0) && (ce->preview_max_height > 0)) {
 		int w = gdk_pixbuf_get_width (pixbuf);
 		int h = gdk_pixbuf_get_height (pixbuf);
+
 		if ((w > ce->preview_max_width) || (h > ce->preview_max_height)) {
 			float      max_w = ce->preview_max_width;
 			float      max_h = ce->preview_max_height;
@@ -2029,11 +1943,9 @@ thumb_loader_done (ThumbLoader *tloader,
 			new_h  = MAX ((int) (h * factor + 0.5), 1);
 
 			scaled = gdk_pixbuf_scale_simple (pixbuf, new_w, new_h, GDK_INTERP_BILINEAR);
+			g_object_unref (idata->preview);
 			idata->preview = scaled;
-		} else {
-			idata->preview = pixbuf;
-			g_object_ref (idata->preview);
-		}
+		} 
 	}
 
 	idata->preview_width = gdk_pixbuf_get_width (idata->preview);
@@ -2042,8 +1954,6 @@ thumb_loader_done (ThumbLoader *tloader,
 	idata->no_preview = ((idata->preview_width == idata->image_width) 
 			     && (idata->preview_height == idata->image_height));
 	
-	debug (DEBUG_INFO, "no preview: %d", idata->no_preview);
-
 	if (idata->no_preview) 
 		if (idata->preview != NULL) {
 			g_object_unref (idata->preview);
@@ -2276,7 +2186,7 @@ catalog_web_exporter_export (CatalogWebExporter *ce)
 
 	if (ce->tmp_location == NULL) {
 		_gtk_error_dialog_run (GTK_WINDOW (ce->window->app), _("Could not create a temporary folder"));
-		g_signal_emit (G_OBJECT (ce), catalog_web_exporter_signals[DONE], 0);
+		g_signal_emit (G_OBJECT (ce), catalog_web_exporter_signals[WEB_EXPORTER_DONE], 0);
 		return;
 	}
 
@@ -2302,11 +2212,11 @@ catalog_web_exporter_export (CatalogWebExporter *ce)
 	thumb_loader_use_cache (ce->tloader, FALSE);
 
 	g_signal_connect (G_OBJECT (ce->tloader), 
-			  "done",
+			  "thumb_done",
 			  G_CALLBACK (thumb_loader_done),
 			  ce);
 	g_signal_connect (G_OBJECT (ce->tloader), 
-			  "error",
+			  "thumb_error",
 			  G_CALLBACK (thumb_loader_error),
 			  ce);
 
