@@ -150,12 +150,7 @@ load_current_image (DialogData *data)
 	g_free (folder);
 	g_free (name_no_ext);
 
-	if (strcmp (fd->path, data->new_path) == 0) {
-		load_next_image (data);
-		return;
-	}
-
-	utf8_name = g_locale_to_utf8 (file_name_from_path (data->new_path), -1, 0, 0, 0);
+	utf8_name = g_filename_to_utf8 (file_name_from_path (data->new_path), -1, 0, 0, 0);
 	message = g_strdup_printf (_("Converting image: %s"), utf8_name);
 
 	gtk_label_set_text (GTK_LABEL (data->progress_label), message);
@@ -177,7 +172,7 @@ show_rename_dialog (DialogData *data)
 	char  *message;
 	char  *utf8_name;
 
-	utf8_name = g_locale_to_utf8 (file_name_from_path (data->new_path), -1, 0, 0, 0);
+	utf8_name = g_filename_to_utf8 (file_name_from_path (data->new_path), -1, 0, 0, 0);
 
 	message = g_strdup_printf (_("An image named \"%s\" is already present. " "Please specify a different name."), utf8_name);
 	
@@ -196,7 +191,10 @@ show_rename_dialog (DialogData *data)
 static void
 save_image_and_remove_original (DialogData *data)
 {
-	GError *error = NULL;
+	GError   *error = NULL;
+
+	if (path_is_file (data->new_path))
+		unlink (data->new_path);
 
 	if (_gdk_pixbuf_savev (data->pixbuf, 
 			       data->new_path, 
@@ -204,14 +202,15 @@ save_image_and_remove_original (DialogData *data)
 			       data->keys, 
 			       data->values,
 			       &error)) {
-		GList *list;
+		GList    *list;
+		FileData *fd = data->current_image->data;
 
 		list = g_list_prepend (NULL, data->new_path);
 		all_windows_notify_files_created (list);
 		g_list_free (list);
 
-		if (data->remove_original) {
-			FileData *fd = data->current_image->data;
+		if (data->remove_original 
+		    && (strcmp (fd->path, data->new_path) != 0)) {
 			unlink (fd->path);
 
 			list = g_list_prepend (NULL, fd->path);
@@ -233,7 +232,7 @@ rename_response_cb (GtkWidget  *dialog,
 	if (response_id == GTK_RESPONSE_OK) {
 		char *new_name, *folder;
 
-		new_name = _gtk_entry_get_locale_text (GTK_ENTRY (data->conv_ren_name_entry));
+		new_name = _gtk_entry_get_filename_text (GTK_ENTRY (data->conv_ren_name_entry));
 		folder = remove_level_from_path (data->new_path);
 
 		g_free (data->new_path);
@@ -304,7 +303,7 @@ loader_done (ImageLoader *il,
 			break;
 
 		case GTH_OVERWRITE_ASK:
-			utf8_name = g_locale_to_utf8 (file_name_from_path (data->new_path), -1, 0, 0, 0);
+			utf8_name = g_filename_to_utf8 (file_name_from_path (data->new_path), -1, 0, 0, 0);
 			message = g_strdup_printf (_("An image named \"%s\" is already present. " "Do you want to overwrite it?"), utf8_name);
 
 			d = _gtk_yesno_dialog_new (GTK_WINDOW (data->dialog),
@@ -354,12 +353,12 @@ ok_cb (GtkWidget  *widget,
 	data->loader = IMAGE_LOADER (image_loader_new (NULL, FALSE));
 
 	g_signal_connect (G_OBJECT (data->loader),
-			  "done",
+			  "image_done",
 			  G_CALLBACK (loader_done),
 			  data);
 
 	g_signal_connect (G_OBJECT (data->loader),
-			  "error",
+			  "image_error",
 			  G_CALLBACK (loader_error),
 			  data);
 
