@@ -3,7 +3,7 @@
 /*
  *  GThumb
  *
- *  Copyright (C) 2001 The Free Software Foundation, Inc.
+ *  Copyright (C) 2001, 2003 Free Software Foundation, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -73,6 +73,7 @@ typedef struct {
 	int           rot_type;    /* 0, 90 ,180, 270 */
 	int           tran_type;   /* mirror, flip */
 	GList        *file_list;
+	GList        *files_changed_list;
 	GList        *current_image;
 	GtkWidget    *viewer;
 } DialogData;
@@ -83,6 +84,13 @@ static void
 destroy_cb (GtkWidget  *widget, 
 	    DialogData *data)
 {
+	if (data->files_changed_list != NULL) {
+		all_windows_notify_files_changed (data->files_changed_list);
+		path_list_free (data->files_changed_list);
+	}
+
+	all_windows_add_monitor ();
+
 	file_data_list_free (data->file_list);
 	g_object_unref (data->gui);
 	g_free (data);
@@ -255,6 +263,8 @@ apply_tran (DialogData *data,
 	if ((rot_type == TRAN_ROTATE_0) && (tran_type == TRAN_NONE))
 		return;
 
+	
+
 	if (rot_type == TRAN_ROTATE_0)
 		tmp1 = g_strdup (fd->path);
 	else {
@@ -279,11 +289,10 @@ apply_tran (DialogData *data,
 			break;
 		}
 
-		if (jpegtran (fd->path, tmp1, transf) != 0) {
+		if (jpegtran (fd->path, tmp1, transf, &err) != 0) {
 			g_free (tmp1);
-			
-			/* FIXME : error dialog here */
-
+			if (err != NULL) 
+				_gtk_error_dialog_from_gerror_run (parent, &err);
 			return;
 		}
 
@@ -342,11 +351,10 @@ apply_tran (DialogData *data,
 			break;
 		}
 
-		if (jpegtran (tmp1, tmp2, transf) != 0) {
+		if (jpegtran (tmp1, tmp2, transf, &err) != 0) {
 			g_free (tmp1);
-			
-			/* FIXME : error dialog here */
-
+			if (err != NULL) 
+				_gtk_error_dialog_from_gerror_run (parent, &err);
 			return;
 		}
 
@@ -392,16 +400,13 @@ apply_tran (DialogData *data,
 		_gtk_error_dialog_from_gerror_run (parent, &err);
 
 	} else {
-		GList *list;
-
 #ifdef HAVE_LIBEXIF
 		if ((rot_type == TRAN_ROTATE_90) || (rot_type == TRAN_ROTATE_270))
 			swap_xy_exif_fields (fd->path);
 #endif
 
-		list = g_list_prepend (NULL, fd->path);
-		all_windows_notify_files_changed (list);
-		g_list_free (list);
+		data->files_changed_list = g_list_prepend (data->files_changed_list, 
+							   g_strdup (fd->path));
 	}
 
 	g_free (e1);
@@ -428,12 +433,14 @@ ok_clicked (GtkWidget  *button,
 		GList     *scan;
 		int        i, n;
 
+		gtk_widget_hide (data->dialog);
+
 		gui = glade_xml_new (GTHUMB_GLADEDIR "/" PROGRESS_GLADE_FILE, 
 				     NULL,
 				     NULL);
 
-		dialog = glade_xml_get_widget   (gui, "progress_dialog");
-		label = glade_xml_get_widget    (gui, "progress_info");
+		dialog = glade_xml_get_widget (gui, "progress_dialog");
+		label = glade_xml_get_widget (gui, "progress_info");
 		bar = glade_xml_get_widget (gui, "progress_progressbar");
 
 		n = g_list_length (data->current_image);
@@ -447,7 +454,7 @@ ok_clicked (GtkWidget  *button,
 		for (scan = data->current_image; scan; scan = scan->next) {
 			FileData *fd = scan->data;
 
-			_gtk_label_set_locale_text (GTK_LABEL (label), fd->name);
+			_gtk_label_set_filename_text (GTK_LABEL (label), fd->name);
 			gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (bar),
 						       (gdouble) i / n);
 
@@ -687,7 +694,7 @@ dlg_jpegtran (GThumbWindow *window)
 
 	/**/
 
-	data = g_new (DialogData, 1);
+	data = g_new0 (DialogData, 1);
 
 	data->file_list = list;
 	data->current_image = list;
@@ -791,6 +798,8 @@ dlg_jpegtran (GThumbWindow *window)
 
 	/* Run dialog. */
 
+	all_windows_remove_monitor ();
+
 	gtk_window_set_transient_for (GTK_WINDOW (data->dialog), GTK_WINDOW (window->app));
 	gtk_window_set_modal (GTK_WINDOW (data->dialog), TRUE); 
 	gtk_widget_show_all (data->dialog);
