@@ -163,12 +163,12 @@ render_frame (GdkDrawable    *drawable,
 
 
 static char *
-escape_locale_text (const char *text) 
+escape_filename (const char *text) 
 {
 	char *utf8_text;
 	char *escaped_text;
 
-	utf8_text = g_locale_to_utf8 (text, -1, NULL, NULL, NULL);
+	utf8_text = g_filename_to_utf8 (text, -1, NULL, NULL, NULL);
 	g_return_val_if_fail (utf8_text != NULL, NULL);
 	
 	escaped_text = g_markup_escape_text (utf8_text, -1);
@@ -210,7 +210,7 @@ get_file_info (GThumbWindow *window)
 	time_t      timer;
 	struct tm  *tm;
 
-	e_filename = escape_locale_text (file_name_from_path (window->image_path));
+	e_filename = escape_filename (file_name_from_path (window->image_path));
 
 	width = image_viewer_get_image_width (IMAGE_VIEWER (window->viewer));
 	height = image_viewer_get_image_height (IMAGE_VIEWER (window->viewer));
@@ -953,13 +953,13 @@ fullscreen_start (FullScreen   *fullscreen,
 
 	current_fullscreen = fullscreen;
 
+	gtk_widget_hide (window->app);
+	gtk_window_present (GTK_WINDOW (fullscreen->window));
+
 	gtk_window_get_position (GTK_WINDOW (window->app),
 				 &main_window_x,
 				 &main_window_y);
 
-	gtk_widget_hide (window->app);
-	gtk_window_present (GTK_WINDOW (fullscreen->window));
-
 	window->fullscreen = TRUE;
 	fullscreen->related_win = window;
 	fullscreen->viewer = window->viewer;
@@ -970,9 +970,10 @@ fullscreen_start (FullScreen   *fullscreen,
 					      FALSE),
 			     GDK_NONE);
 
+	gtk_widget_reparent (window->viewer, fullscreen->window); 
+
 	if (! eel_gconf_get_boolean (PREF_BLACK_BACKGROUND, FALSE))
 		image_viewer_set_black_background (IMAGE_VIEWER (fullscreen->viewer), TRUE);
-	gtk_widget_reparent (window->viewer, fullscreen->window); 
 
 	/* capture keyboard events. */
 
